#########################
Contributing to *groupyr*
#########################

*Groupyr* is an open-source software project. This means that you are welcome
to use it (see `LICENSE
<https://github.com/richford/groupyr/blob/main/LICENSE>`_ for details).

It also means that we welcome contributions from developers outside of our
research collaboration. We love contributions and we will credit them
appropriately!

We've written a more detailed contribution guide `here
<https://github.com/richford/groupyr/blob/main/.github/CONTRIBUTING.md>`_.
